from ..cw_model import CWModel


class ExpenseType(CWModel):

    def __init__(self, json_dict=None):
        self.id = None  # (Integer)
        self.name = None  # *(String(30))
        self.amountCaption = None  # *(String)
        self.reimbursementRate = None  # (Number)
        self.billExpenses = None  # *(Enum)
        self.invoiceMarkupOption = None  # *(Enum)
        self.invoiceMarkupAmount = None  # (Number)
        self.advancedAmountFlag = None  # (Boolean)
        self.mileageFlag = None  # (Boolean)
        self.quantityFlag = None  # (Boolean)
        self.inactiveFlag = None  # (Boolean)
        self.maxAmount = None  # (Number)
        self._info = None  # (Metadata)

        # initialize object with json dict
        super().__init__(json_dict)



from ..cw_controller import CWController
# Class for /procurement/catalog
from . import catalog_item


class CatalogItemAPI(CWController):
    def __init__(self, **kwargs):
        self.module_url = 'procurement'
        self.module = 'catalog'
        self._class = catalog_item.CatalogItem
        super().__init__(**kwargs)  # instance gets passed to parent object

    def get_catalog_items(self):
        return super()._get()

    def create_catalog_item(self, a_catalog_item):
        return super()._create(a_catalog_item)

    def get_catalog_items_count(self):
        return super()._get_count()

    def get_catalog_item_by_id(self, catalog_item_id):
        return super()._get_by_id(catalog_item_id)

    def delete_catalog_item_by_id(self, catalog_item_id):
        super()._delete_by_id(catalog_item_id)

    def replace_catalog_item(self, catalog_item_id):
        pass

    def update_catalog_item(self, catalog_item_id, key, value):
        return super()._update(catalog_item_id, key, value)


from ..cw_controller import CWController
# Class for /procurement/manufacturers
from . import manufacturer


class ManufacturerAPI(CWController):
    def __init__(self, **kwargs):
        self.module_url = 'procurement'
        self.module = 'manufacturers'
        self._class = manufacturer.Manufacturer
        super().__init__(**kwargs)  # instance gets passed to parent object

    def get_manufacturers(self):
        return super()._get()

    def create_manufacturer(self, a_manufacturer):
        return super()._create(a_manufacturer)

    def get_manufacturers_count(self):
        return super()._get_count()

    def get_manufacturer_by_id(self, manufacturer_id):
        return super()._get_by_id(manufacturer_id)

    def delete_manufacturer_by_id(self, manufacturer_id):
        super()._delete_by_id(manufacturer_id)

    def replace_manufacturer(self, manufacturer_id):
        pass

    def update_manufacturer(self, manufacturer_id, key, value):
        return super()._update(manufacturer_id, key, value)


from ..cw_controller import CWController
# Class for /company/agreements
from . import agreement


class AgreementsAPI(CWController):

    def __init__(self, **kwargs):
        self.module_url = 'finance'
        self.module = 'agreements'
        self._class = agreement.Agreement
        super().__init__(**kwargs)  # instance gets passed to parent object

    def get_agreements(self):
        return super()._get()

    def create_agreement(self, a_agreement):
        return super()._create(a_agreement)

    def get_agreements_count(self):
        return super()._get_count()

    def get_agreement_by_id(self, agreement_id):
        return super()._get_by_id(agreement_id)

    def delete_agreement_by_id(self, agreement_id   ):
        super()._delete_by_id(agreement_id)

    def replace_agreement(self, agreement_id):
        pass

    def update_agreement(self, agreement_id, key, value):
        return super()._update(agreement_id, key, value)

    def merge_agreement(self, agreement_id):
        pass

#    def create_configuration_association(self, user_headers, agreement_id, config_id):
#        # /agreements/{id}/configurations
#         self.root_path = self.root_path + '/agreements/{}'.format(agreement_id)
# 
#         dict_post = {'id': config_id}
#         json_results = self.configurations.post(user_data=dict_post, user_headers=user_headers)
#         #      status_code = json_results.status_code
#         return json_results

    def get_agreement_configurations(self):
        pass



from ..cw_model import CWModel


class AgreementAdjustment(CWModel):

    def __init__(self, json_dict=None):
        self.id = None  # (Integer)
        self.amount = None  # (Number)
        self.description = None  # (String(1000))
        self.effectiveDate = None  # (String)
        self.agreementId = None  # (Integer)
        self._info = None  # (Metadata)

        # initialize object with json dict
        super().__init__(json_dict)



from ..cw_model import CWModel


class Link(CWModel):

    def __init__(self, json_dict=None):
        self.id = None  # (Integer)
        self.name = None  # *(String(50))
        self.tableReferenceId = None  # *(Integer)
        self.url = None  # (String(1000))
        self._info = None  # (Metadata)

        # initialize object with json dict
        super().__init__(json_dict)
